Index: chrome/browser/extensions/api/record/record_api_test.cc |
=================================================================== |
--- chrome/browser/extensions/api/record/record_api_test.cc (revision 176046) |
+++ chrome/browser/extensions/api/record/record_api_test.cc (working copy) |
@@ -217,14 +217,13 @@ |
// Run a capture, using standard URL test list and the specified |
// user data dir. Return via |out_list| the list of error URLs, |
// if any, resulting from the capture. And return directly the |
// RecordCaptureURLsFunction that was used, so that its state may be |
// queried. |
- scoped_refptr<RecordCaptureURLsFunction> RunCapture( |
- const FilePath& user_data_dir, |
+ scoped_refptr<CaptureURLsFunction> RunCapture(const FilePath& user_data_dir, |
scoped_ptr<base::ListValue>* out_list) { |
- scoped_refptr<RecordCaptureURLsFunction> capture_function( |
- new RecordCaptureURLsFunction(new TestProcessStrategy(&temp_files_))); |
+ scoped_refptr<CaptureURLsFunction> capture_function( |
+ new CaptureURLsFunction(new TestProcessStrategy(&temp_files_))); |
std::string escaped_user_data_dir; |
ReplaceChars(user_data_dir.AsUTF8Unsafe(), "\\", "\\\\", |
@@ -278,7 +277,7 @@ |
scoped_ptr<base::ListValue> result; |
EXPECT_TRUE(user_data_dir.CreateUniqueTempDir()); |
- scoped_refptr<RecordCaptureURLsFunction> capture_URLs_function = |
+ scoped_refptr<CaptureURLsFunction> capture_URLs_function = |
RunCapture(user_data_dir.path(), &result); |
// Check that user-data-dir switch has been properly overridden. |
@@ -315,8 +314,7 @@ |
ReplaceChars(user_data_dir.path().AsUTF8Unsafe(), "\\", "\\\\", |
&escaped_user_data_dir); |
- scoped_refptr<RecordReplayURLsFunction> playback_function( |
- new RecordReplayURLsFunction( |
+ scoped_refptr<ReplayURLsFunction> playback_function(new ReplayURLsFunction( |
new TestProcessStrategy(&temp_files_))); |
scoped_ptr<base::DictionaryValue> result(utils::ToDictionary( |
utils::RunFunctionAndReturnSingleResult(playback_function, |
@@ -217,14 +217,13 @@ |
// user data dir. Return via |out_list| the list of error URLs, |
// if any, resulting from the capture. And return directly the |
- // RecordCaptureURLsFunction that was used, so that its state may be |
+ // CaptureURLsFunction that was used, so that its state may be |
// queried. |